@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000-2008 the xine project
+ * Copyright (C) 2000-2011 the xine project
  *
  * This file is part of xine, a unix video player.
  * 
@@ -1270,8 +1270,10 @@ static void event_listener(void *user_data, const xine_event_t *event) {
       gGui->mixer.amp_level = (aevent->left + aevent->right) / 2;
       if(gGui->mixer.method == SOFTWARE_MIXER) {
 	gGui->mixer.mute = aevent->mute;
-	xitk_slider_set_pos(panel->mixer.slider, gGui->mixer.amp_level);
-	xitk_checkbox_set_state(panel->mixer.mute, gGui->mixer.mute);
+	if (panel) {
+	  xitk_slider_set_pos(panel->mixer.slider, gGui->mixer.amp_level);
+	  xitk_checkbox_set_state(panel->mixer.mute, gGui->mixer.mute);
+        }
       }
     }
     break;
