@@ -1,5 +1,5 @@
 /* 
- * Copyright (C) 2000-2008 the xine project
+ * Copyright (C) 2000-2013 the xine project
  * 
  * This file is part of xine, a unix video player.
  * 
@@ -214,7 +214,7 @@ static void menu_playlist_ctrl(xitk_widget_t *w, xitk_menu_entry_t *me, void *da
 }
 static void menu_playlist_from(xitk_widget_t *w, xitk_menu_entry_t *me, void *data) {
   int       num_mrls;
-  char    **autoplay_mrls = xine_get_autoplay_mrls (__xineui_global_xine_instance, me->menu, &num_mrls);
+  const char * const *autoplay_mrls = xine_get_autoplay_mrls (__xineui_global_xine_instance, me->menu, &num_mrls);
 
   if(autoplay_mrls) {
     int j;
