@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000-2008 the xine project
+ * Copyright (C) 2000-2013 the xine project
  * 
  * This file is part of xine, a unix video player.
  * 
@@ -882,6 +882,11 @@ static void panel_slider_cb(xitk_widget_t *w, void *data, int pos) {
 static void panel_handle_event(XEvent *event, void *data) {
 
   switch(event->type) {
+  case DestroyNotify:
+    if(gGui->panel_window == event->xany.window)
+      gui_exit(NULL, NULL);
+    break;
+
   case ButtonPress:
     {
       XButtonEvent *bevent = (XButtonEvent *) event;
@@ -1161,6 +1166,14 @@ void panel_init (void) {
 				      CWBackPixel | CWBorderPixel | CWColormap | CWOverrideRedirect,
 				      &attr);
 
+  {
+    /* prevent window manager from killing us through exit() when user closes panel.
+       That wont work with OpenGL* video out because libGL does install an exit handler
+       that calls X functions - while video out loop still tries the same -> deadlock */
+    Atom wm_delete_window = XInternAtom(gGui->display, "WM_DELETE_WINDOW", False);
+    XSetWMProtocols(gGui->display, gGui->panel_window, &wm_delete_window, 1);
+  }
+
   XmbSetWMProperties(gGui->display, gGui->panel_window, title, title, NULL, 0,
                      &hint, NULL, NULL);
 
